<?php

namespace FM\Service;

use FM\Factory\EquipamentoFactory;
use FM\Factory\ImgEquipamentoFactory;
use FM\Factory\RelacescoposequipFactory;
use FM\Service\FileServerService;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class EquipamentoService {

    protected $EquipamentoFactory;
    protected $ImgEquipamentoFactory;
    protected $RelacescoposequipFactory;
    protected $FileServerService;
    protected $Environment;
    protected $newCode;
    protected $connection;
    protected $fileServerApiKeys;

    public function __construct (EquipamentoFactory $EquipamentoFactory, ImgEquipamentoFactory $ImgEquipamentoFactory, RelacescoposequipFactory $RelacescoposequipFactory, FileServerService $FileServerService, EntityManager $entityManager, Environment $Environment, NewCode $newCode, $fileServerApiKeys) {
        $this->EquipamentoFactory = $EquipamentoFactory;
        $this->ImgEquipamentoFactory = $ImgEquipamentoFactory;
        $this->RelacescoposequipFactory = $RelacescoposequipFactory;
        $this->FileServerService = $FileServerService;
        $this->connection = $entityManager->getConnection();
        $this->Environment = $Environment;
        $this->newCode = $newCode;
        $this->fileServerApiKeys = $fileServerApiKeys;
    }
    
    public function dadosAtivos(){
        return $this->EquipamentoFactory->dadosAtivos();
    }
    
    public function ativo($nr){
        return $this->EquipamentoFactory->ativo($nr);
    }
    
    public function insumosDeManutencao($nr){
        return $this->EquipamentoFactory->insumosDeManutencao($nr);
    }
    
    public function atualizarAtivo($params){
        $this->connection->beginTransaction();
        
         try {
            $row = $this->FileServerService->uploadImagensManut($params['IMAGENS']);
            foreach ($row as $file) {
                $this->ImgEquipamentoFactory->insertImg(array(
                    "NRIMGEQUIPAMENTO" => $this->newCode->getCodeByTableName('FCM_IMGEQUIPAMENTO', 20, 1, 10, true),
                    "NREQUIPAMENTO" => intval($params['NR']),
                    "DSCAMINHO" => $file['DS'],
                    "NRORG" => 20,
                    "DSTYPE" => $file['DSTYPE'],
                    "NRSIZE" => $file['QTSIZE']
                ));
            }
            
            $this->RelacescoposequipFactory->deletRelacEscopoEquip(array(
                "NREQUIPAMENTO" => intval($params['NR'])
            ));
            
            foreach($params['ESCOPO'] as $NrEscopo){
                $this->RelacescoposequipFactory->insertRelacEscopoEquip(array(
                    "RELACESCOPOSEQUIP" => $this->newCode->getCodeByTableName('FCM_RELACESCOPOSEQUIP', 20, 1, 10, true),
                    "NREQUIPAMENTO" => intval($params['NR']),
                    "NRESCOPOMANUT" => $NrEscopo,
                    "NRORG" => 20
                ));
            }
            
            $this->EquipamentoFactory->updateAtivo(array(
                "NRCATEGORIAEQUIP" => $params['CATEGORIA'],
                "IDSITUACAO" => $params['SITUACAO'],
                "NREQUIPAMENTO" => intval($params['NR'])
            ));
            
            $this->connection->commit();
            $response = "OK";
        } catch(\Exception $e) {
            $this->connection->rollback();
            $response = ($e->getMessage());
        }
        
        return $response;
    }
    
    public function insertAtivo($params){
        $this->connection->beginTransaction();
        
        try {
            $nrequipamento = $this->newCode->getCodeByTableName('FCM_EQUIPAMENTO', 20, 1, 10, true);
        
            $this->EquipamentoFactory->insertAtivo(array(
                "NREQUIPAMENTO" => $nrequipamento,
                "NMEQUIPAMENTO" => $params['NOME'],
                "CDEQUIPAMENTO" => $params['CODIGO'],
                "NRCATEGORIAEQUIP" => $params['CATEGORIA'],
                "IDSITUACAO" => $params['SITUACAO'],
                "NRORG" => 20
            ));
            $row = $this->FileServerService->uploadImagensManut($params['IMAGENS']);
            foreach ($row as $file) {
                $this->ImgEquipamentoFactory->insertImg(array(
                    "NRIMGEQUIPAMENTO" => $this->newCode->getCodeByTableName('FCM_IMGEQUIPAMENTO', 20, 1, 10, true),
                    "NREQUIPAMENTO" => $nrequipamento,
                    "DSCAMINHO" => $file['DS'],
                    "NRORG" => 20,
                    "DSTYPE" => $file['DSTYPE'],
                    "NRSIZE" => $file['QTSIZE']
                ));
            }
            
            foreach($params['ESCOPO'] as $NrEscopo){
                $this->RelacescoposequipFactory->insertRelacEscopoEquip(array(
                    "RELACESCOPOSEQUIP" => $this->newCode->getCodeByTableName('FCM_RELACESCOPOSEQUIP', 20, 1, 10, true),
                    "NREQUIPAMENTO" => $nrequipamento,
                    "NRESCOPOMANUT" => $NrEscopo,
                    "NRORG" => 20
                ));
            }
            
            $this->connection->commit();
            $response = "OK";
        } catch(\Exception $e) {
            $this->connection->rollback();
            $response = ($e->getMessage());
        }
        return $response;
    }
}

?>