/* eslint-disable */
import {
  Metadata, Http,
} from '@zeedhi/core';
import {
  AlertService, Button, DialogService, LoadingService, Select, Text, Tooltip,
} from '@zeedhi/common';

export class ControllerSensores {
  private contadorUnico: any;
  private contadorDuplo: any;
  private contadorGeral: any;

  private isItFirst: boolean = false;

  private changeButtons(cond: boolean, duplo: boolean = false) {
    Metadata.getInstance<Select>('SelectSensorEntrada').disabled = cond;
    if (duplo) {
      Metadata.getInstance<Select>('SelectSensorSaida').disabled = cond;
    }
    Metadata.getInstance<Button>('btnIniciarContador').disabled = cond;
    Metadata.getInstance<Button>('btnInterromperContador').iconName = (cond) ? 'mdi-pause' : 'mdi-reload';
    Metadata.getInstance<Tooltip>('tooltipCancelReset').label = (cond) ? 'Pausar contagem' : 'Reiniciar contagem';
  }

  public iniciarContagem() {
    if (window.location.pathname === '/SentidoUnico') {
      this.contagemSentidoUnico();
    } else if (window.location.pathname === '/SentidoDuplo') {
      this.contagemSentidoDuplo();
    } else if (window.location.pathname === '/SentidoGeral') {
      this.contagemSentidoGeral();
    }
  }

  public contagemSentidoUnico() {
    const ID = Metadata.getInstance<Select>('SelectSensorEntrada').value;
    const ID2 = Metadata.getInstance<Select>('SelectSensorSaida').value;
    if ((ID || ID !== null) && (ID2 || ID2 !== null)) {
      LoadingService.show('Inciando...');
      Http.get(`/getInicioEDateSensor?IP=${ID}&IP2=${ID2}`).then((response: any) => {
        LoadingService.hide();
        if (response.data.length && (response.data[0][0].IDMONITORAMENTO === 'S' || response.data[1][0].IDMONITORAMENTO === 'S')) {
          const DATAHORA = response.data[0][0].DATARESET.split(' ');
          DialogService.show({
            name: 'basic-dialog',
            type: 'info',
            title: 'Contagem encontrada',
            text: `Foi encontrada uma contagem já iniciada em um dos sensores selecionado.\nDeseja <b>reiniciar</b> a contagem ou <b>continuar</b> com os dados existente em ambos os sensores?`,
            buttons: [
              {
                name: 'zerar',
                component: 'ZdButton',
                outline: true,
                label: 'Reiniciar',
                events: {
                  click: () => this.iniciarContadorUnic('S'),
                },
              },
              {
                name: 'comtinuar',
                component: 'ZdButton',
                label: 'Continuar',
                events: {
                  click: () => this.iniciarContadorUnic('N'),
                },
              },
            ],
          });
        } else {
          this.iniciarContadorUnic('N');
        }
      });
    } else {
      this.alertMensagem('Selecione um sensor.', 'error');
    }
  }

  public contagemSentidoDuplo() {
    const ID = Metadata.getInstance<Select>('SelectSensorEntrada').value;
    if (ID || ID !== null) {
      LoadingService.show('Inciando...');
      Http.get(`/getInicioEDateSensor?IP=${ID}`).then((response: any) => {
        LoadingService.hide();
        if (response.data[0].IDMONITORAMENTO === 'S') {
          const DATAHORA = response.data[0].DATARESET.split(' ');
          DialogService.show({
            name: 'basic-dialog',
            type: 'info',
            title: 'Contagem encontrada',
            text: `Foi encontrada uma contagem já iniciada em ${DATAHORA[1]} às ${DATAHORA[0]}.\nDeseja <b>reiniciar</b> a contagem ou <b>continuar</b> com os dados existente?`,
            buttons: [
              {
                name: 'zerar',
                component: 'ZdButton',
                outline: true,
                label: 'Reiniciar',
                events: {
                  click: () => this.iniciarContadorDuplo('S'),
                },
              },
              {
                name: 'comtinuar',
                component: 'ZdButton',
                label: 'Continuar',
                events: {
                  click: () => this.iniciarContadorDuplo('N'),
                },
              },
            ],
          });
        } else {
          this.iniciarContadorDuplo('N');
        }
      });
    } else {
      this.alertMensagem('Selecione um sensor.', 'error');
    }
  }

  public contagemSentidoGeral() {
    const ID = Metadata.getInstance<Select>('SelectSensorEntrada').value;
    if (ID || ID !== null) {
      LoadingService.show('Inciando...');
      Http.get(`/getInicioEDateSensor?IP=${ID}`).then((response: any) => {
        LoadingService.hide();
        if (response.data[0].IDMONITORAMENTO === 'S') {
          const DATAHORA = response.data[0].DATARESET.split(' ');
          DialogService.show({
            name: 'basic-dialog',
            type: 'info',
            title: 'Contagem encontrada',
            text: `Foi encontrada uma contagem já iniciada em ${DATAHORA[1]} às ${DATAHORA[0]}.\nDeseja <b>reiniciar</b> a contagem ou <b>continuar</b> com os dados existente?`,
            buttons: [
              {
                name: 'zerar',
                component: 'ZdButton',
                outline: true,
                label: 'Reiniciar',
                events: {
                  click: () => this.iniciarContadorGeral('S'),
                },
              },
              {
                name: 'comtinuar',
                component: 'ZdButton',
                label: 'Continuar',
                events: {
                  click: () => this.iniciarContadorGeral('N'),
                },
              },
            ],
          });
        } else {
          this.iniciarContadorGeral('N');
        }
      });
    } else {
      this.alertMensagem('Selecione um sensor.', 'error');
    }
  }

  public async encerrarContagem({ component }:any) {
    const ID = Metadata.getInstance<Select>('SelectSensorEntrada').value;
    
    // LoadingService.show((component.iconName === 'mdi-reload') ? 'Reiniciando...' : 'Pausando...');
    // await Http.get(`/${((component.iconName === 'mdi-reload') ? 'resetCount...' : 'stopCount...')}?IP=${ID}`);
    
    if(component.iconName === 'mdi-reload') {
      LoadingService.show('Reiniciando...');
      await Http.get(`/resetCount?IP=${ID}`);
      if (window.location.pathname === '/SentidoUnico') {
        const ID2 = Metadata.getInstance<Select>('SelectSensorSaida').value;
        await Http.get(`/resetCount?IP=${ID2}`);
        Metadata.getInstance<Text>('ValorPlacarEntrada').text = '0';
          Metadata.getInstance<Text>('ValorPlacarSaida').text = '0';
      } else if (window.location.pathname === '/SentidoDuplo') {
        Metadata.getInstance<Text>('ValorPlacarEntradaSaida').text = '0';
      }
      Metadata.getInstance<Text>('ValorPlacarOcupacao').text = '0';
    } else {
      LoadingService.show('Pausando...');
      await Http.get(`/stopCount?IP=${ID}`);
      if (window.location.pathname === '/SentidoUnico') {
        const ID2 = Metadata.getInstance<Select>('SelectSensorSaida').value;
        await Http.get(`/stopCount?IP=${ID2}`);
        this.changeButtons(false, true);
        clearInterval(this.contadorUnico);
      } else {
        this.changeButtons(false);
        if (window.location.pathname === '/SentidoDuplo') {
          clearInterval(this.contadorDuplo);
        } else {
          clearInterval(this.contadorGeral);
        }
      }
    }
    LoadingService.hide();
  }
  
  public alertMensagem(mensagem: string, tipoMensagem: string = 'success') {
    AlertService.show({
      name: 'AlertInformativo',
      text: mensagem,
      timeout: 3000,
      top: true,
      left: false,
      color: tipoMensagem,
    })
  }
  
  public iniciarContadorGeral(statusReset: string) {
    this.isItFirst = true;
    DialogService.hide();
    this.changeButtons(true);
    const ID = Metadata.getInstance<Select>('SelectSensorEntrada').value;
    this.contadorGeral = setInterval(() => {
      Http.get(`/getCount?FIRST=${this.isItFirst}&RESET=${statusReset}&IDSENSOR=${ID}`).then((response: any) => {
        const valorEntrada = Metadata.getInstance<Text>('ValorPlacarOcupacao');
        valorEntrada.text = String(response.data);
      })
      this.isItFirst = false;
    }, 5000);
  }
  
  public iniciarContadorDuplo(statusReset: string) {
    this.isItFirst = true;
    DialogService.hide();
    this.changeButtons(true);
    const ID = Metadata.getInstance<Select>('SelectSensorEntrada').value;
    this.contadorDuplo = setInterval(() => {
      Http.get(`/getCount?FIRST=${this.isItFirst}&RESET=${statusReset}&IDSENSOR=${ID}`).then((response: any) => {
        const valorEntrada = Metadata.getInstance<Text>('ValorPlacarEntradaSaida');
        valorEntrada.text = String(response.data);
        const valorOcupacao = Metadata.getInstance<Text>('ValorPlacarOcupacao');
        valorOcupacao.text = String(Math.floor(response.data / 2));
      })
      this.isItFirst = false;
    }, 5000);
  }
  
  public iniciarContadorUnic(statusReset: string) {
    this.isItFirst = true;
    DialogService.hide();
    this.changeButtons(true, true);
    const ID = Metadata.getInstance<Select>('SelectSensorEntrada').value;
    const ID2 = Metadata.getInstance<Select>('SelectSensorSaida').value;
    this.contadorUnico = setInterval(() => {
      let ocupation = 0;
       Http.get(`/getCount?FIRST=${this.isItFirst}&RESET=${statusReset}&IDSENSOR=${ID}`).then((response: any) => {
        Metadata.getInstance<Text>('ValorPlacarEntrada').text = String(response.data);
        ocupation = response.data;
      }).then(() => {
        Http.get(`/getCount?FIRST=${this.isItFirst}&RESET=${statusReset}&IDSENSOR=${ID2}`).then((response: any) => {
          Metadata.getInstance<Text>('ValorPlacarSaida').text = String(response.data);
          ocupation = (response.data > ocupation) ? 0 : ocupation - response.data;
        })
      }).then(() => {
        Metadata.getInstance<Text>('ValorPlacarOcupacao').text = String(ocupation);
        this.isItFirst = false;
      })
    }, 5000);
  }

  public encerrarInteval({ component }: any) {
    if(component.name === 'frame_Geral') {
      clearInterval(this.contadorGeral);
    } else if (component.name === 'frame_Unico') {
      clearInterval(this.contadorUnico);
    } else if (component.name === 'frame_Duplo') {
      clearInterval(this.contadorDuplo);
    }
  }
}
